{% extends "base.html" %}

{% block title %}Endpoints{% endblock %}

{% block content %}
<h1>Endpoints</h1>
<table>
<thead><tr><th>Path</th><th>View</th><th>Pattern</th></tr></thead>
<tbody>
{% for endpoint in endpoints %}
    <tr><td>{{ endpoint.path }}</td><td>{{ endpoint.view }}</td><td><code>{{ endpoint.pattern }}</code></td></tr>
{% endfor %}
</tbody>
</table>
{% endblock %}
